@@ -1375,6 +1375,20 @@ INFO: Unable to find MCDRAM numa nodes:
 
         return self._nodes_with_cpus > 1
 
+    def get_hbw_nodes(self):
+        """returns comma separated list of HBW nodes if they exist,
+        empty string otherwise; note: the function uses memkind"""
+
+        localhost = micp_connect.LocalConnect()
+        pid_get_hwb_nodes = localhost.Popen('memkind-hbw-nodes')
+        stdout, __ = pid_get_hwb_nodes.communicate()
+
+        hwb_nodes = stdout.rstrip()
+        if pid_get_hwb_nodes.returncode or not hwb_nodes:
+            return ''
+        else:
+            return hwb_nodes
+
     def get_number_of_nodes_with_cpus(self):
         """returns the number of NUMA nodes with CPUs"""
         return self._nodes_with_cpus
@@ -1616,6 +1630,13 @@ class Info(InfoKNXLB, Borg):
         except AttributeError:
             return False
 
+    def get_hbw_nodes(self):
+        """returns comma separated list of HBW nodes if they exist,
+        empty string otherwise; note: the function uses memkind"""
+        try:
+            return self._device.get_hbw_nodes()
+        except AttributeError:
+            return ''
 
     def get_number_of_nodes_with_cpus(self):
         """returns number of NUMA nodes with CPUs
