@@ -333,7 +333,8 @@ class Kernel(object):
         try:
             return [os.path.join(pp, libName) for pp in ldLibraryPath if os.path.exists(os.path.join(pp, libName))][0]
         except (KeyError, IndexError):
-            raise micp_common.NoSharedObjectError()
+            raise micp_common.MissingDependenciesError(
+                micp_common.DEP_REDIST)
 
     def mic_ld_library_path(self):
         """
